use strict;
use warnings;

use assign::0;

my [$a1, $b1] = [];

warn "warn line 8";

my [
    $a2,
    $b2,
] =

    []
    ;

die "die line 18";
